Mite: the mighty performance testing framework
==============================================

Mite is a performance testing framework created by the performance
testing in Sky UKʼs Identity group.  The philosophy driving the effort
was simple:

1. Scalability.  The apps that we test are scalable, distributed systems;
   our performance testing framework should be as well.
2. Maintainability.  As software engineers, we have a full arsenal of
   information organization and reuse techniques.  We should treat our
   performance tests as code, and bring these same techniques to bear.
3. Snakiness.  Python is the best language for us to accomplish our
   goals for the project.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   components
   journeys
   volume-model
   config
   design-deployment
   prometheus
   stats


..
   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
